==> mono_2.6.7.orig.tar.gz: mono-2.6.7/mcs/class/System.ServiceModel/System.ServiceModel.Configuration/CustomBindingCollectionElement.cs <==
//
// CustomBindingCollectionElement.cs
//
// Author:
//	Atsushi Enomoto <atsushi@ximian.com>
//
// Copyright (C) 2006 Novell, Inc.  http://www.novell.com
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Configuration;
using System.Net;
using System.Net.Security;
using System.Reflection;
using System.Security.Cryptography.X509Certificates;
using System.Security.Principal;
using System.IdentityModel.Claims;
using System.IdentityModel.Policy;
using System.IdentityModel.Tokens;
using System.ServiceModel;
using System.ServiceModel.Channels;
using System.ServiceModel.Description;
using System.ServiceModel.Diagnostics;
using System.ServiceModel.Dispatcher;
using System.ServiceModel.MsmqIntegration;
using System.ServiceModel.PeerResolvers;
using System.ServiceModel.Security;
using System.Runtime.Serialization;
using System.Text;
using System.Xml;

namespace System.ServiceModel.Configuration
{
	public sealed class CustomBindingCollectionElement
		 : BindingCollectionElement
	{

		// Properties

		[ConfigurationProperty ("",
			 Options = ConfigurationPropertyOptions.IsDefaultCollection,
			IsDefaultCollection = true)]
		public CustomBindingElementCollection Bindings {
			get { return (CustomBindingElementCollection) this [String.Empty]; }
		}

		public override ReadOnlyCollection<IBindingConfigurationElement> ConfiguredBindings {
			get {
				List<IBindingConfigurationElement> list = new List<IBindingConfigurationElement> ();
				CustomBindingElementCollection bindings = Bindings;
				for (int i = 0; i < bindings.Count; i++)
					list.Add (bindings [i]);
				return new ReadOnlyCollection<IBindingConfigurationElement> (list);
			}
		}

		protected override ConfigurationPropertyCollection Properties {
			get { return base.Properties; }
		}

		public override Type BindingType {
			get { return typeof (CustomBinding); }
		}


		public override bool ContainsKey (string name) {
			throw new NotImplementedException ();
		}

		protected internal override Binding GetDefault () {
			throw new NotImplementedException ();
		}

		protected internal override bool TryAdd (string name, Binding binding, System.Configuration.Configuration config) {
			throw new NotImplementedException ();
		}
	}

}

==> mono_2.10.8.1.orig.tar.gz: mono-2.10.8.1/mcs/class/System.ServiceModel/System.ServiceModel.Configuration/CustomBindingCollectionElement.cs <==
//
// CustomBindingCollectionElement.cs
//
// Author:
//	Atsushi Enomoto <atsushi@ximian.com>
//
// Copyright (C) 2006 Novell, Inc.  http://www.novell.com
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Configuration;
using System.Net;
using System.Net.Security;
using System.Reflection;
using System.Security.Cryptography.X509Certificates;
using System.Security.Principal;
using System.IdentityModel.Claims;
using System.IdentityModel.Policy;
using System.IdentityModel.Tokens;
using System.ServiceModel;
using System.ServiceModel.Channels;
using System.ServiceModel.Description;
using System.ServiceModel.Diagnostics;
using System.ServiceModel.Dispatcher;
using System.ServiceModel.MsmqIntegration;
using System.ServiceModel.PeerResolvers;
using System.ServiceModel.Security;
using System.Runtime.Serialization;
using System.Text;
using System.Xml;

namespace System.ServiceModel.Configuration
{
	public sealed class CustomBindingCollectionElement
		 : BindingCollectionElement
	{

		// Properties

		[ConfigurationProperty ("",
			 Options = ConfigurationPropertyOptions.IsDefaultCollection,
			IsDefaultCollection = true)]
		public CustomBindingElementCollection Bindings {
			get { return (CustomBindingElementCollection) this [String.Empty]; }
		}

		public override ReadOnlyCollection<IBindingConfigurationElement> ConfiguredBindings {
			get {
				List<IBindingConfigurationElement> list = new List<IBindingConfigurationElement> ();
				CustomBindingElementCollection bindings = Bindings;
				for (int i = 0; i < bindings.Count; i++)
					list.Add (bindings [i]);
				return new ReadOnlyCollection<IBindingConfigurationElement> (list);
			}
		}

		protected override ConfigurationPropertyCollection Properties {
			get { return base.Properties; }
		}

		public override Type BindingType {
			get { return typeof (CustomBinding); }
		}


		public override bool ContainsKey (string name) {
			throw new NotImplementedException ();
		}

		protected internal override Binding GetDefault ()
		{
			return new CustomBinding ();
		}

		protected internal override bool TryAdd (string name, Binding binding, System.Configuration.Configuration config) {
			throw new NotImplementedException ();
		}
	}

}
